<?php
/* $Id: romanian-utf-8.inc.php,v 2.118.2.1 2006/02/17 12:43:00 lem9 Exp $ */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Du', 'Lu', 'Ma', 'Mi', 'Jo', 'Vi', 'Sa');
$month = array('Ian', 'Feb', 'Mar', 'Apr', 'Mai', 'Iun', 'Iul', 'Aug', 'Sep', 'Oct', 'Noi', 'Dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%B %d, %Y at %I:%M %p';

$timespanfmt = '%s zile, %s ore, %s minute si %s secunde';

$strAPrimaryKey = 'A fost adaugat o cheie primara la %s';
$strAbortedClients = 'Intrerupt';
$strAbsolutePathToDocSqlDir = 'Va rugam introduceti calea absoluta al serverului web la directorul docSQL';
$strAccessDenied = 'Acces interzis';
$strAccessDeniedExplanation = 'phpMyAdmin a incercat sa se conecteze la serverul de MySQL dar acesta a respins conexiunea. Ar trebui verificat daca datele din config.inc.php sunt corecte.';
$strAction = 'Actiune';
$strAddAutoIncrement = 'Adauga valoare pentru AUTO_INCREMENT';
$strAddConstraints = 'Adauga constrangere';
$strAddDeleteColumn = 'Adauga/Sterge coloane';
$strAddDeleteRow = 'Adauga/Sterge criteriu';
$strAddDropDatabase = 'Adaugare optiune STERGE BAZA DE DATE';
$strAddFields = 'Adauga %s camp(uri)';
$strAddHeaderComment = 'Adaugare comentariu la header (\\n inseamna delimitare de rand)';
$strAddIfNotExists = 'Adaugare DACA NU EXISTA';
$strAddIntoComments = 'Adaugare la comentarii';
$strAddNewField = 'Adauga camp nou';
$strAddPrivilegesOnDb = 'Adauga drepturi la baza de date urmatoare';
$strAddPrivilegesOnTbl = 'Adauga drepturi la urmatorul tabel';
$strAddSearchConditions = 'Adauga conditie de cautare (parte a comenzii "where"):';
$strAddToIndex = 'Adauga la coloana(ele) index &nbsp;%s&nbsp;';
$strAddUser = 'Adauga un utilizator nou';
$strAddUserMessage = 'Ati adaugat un nou utilizator.';
$strAddedColumnComment = 'Sa adaugat comentariu la coloana';
$strAddedColumnRelation = 'Sa adaugat o relatie la coloana';
$strAdministration = 'Administrare';
$strAffectedRows = 'Linii afectate:';
$strAfter = 'Dupa %s';
$strAfterInsertBack = 'Revenire';
$strAfterInsertNewInsert = 'Adauga o noua inregistrare';
$strAfterInsertNext = 'Editeaza randul urmator';
$strAfterInsertSame = 'Inapoi la aceasta pagina';
$strAll = 'Toate';
$strAllTableSameWidth = 'arata toate tabelele cu aceeasi marime?';
$strAlterOrderBy = 'Alterare ordine tabel dupa (Alter table order by)';
$strAnIndex = 'A fost adaugat un index la %s';
$strAnalyzeTable = 'Analizare tabel';
$strAnd = 'Si (And)';
$strAny = 'Oricare';
$strAnyHost = 'Oricare host';
$strAnyUser = 'Oricare utilizator';
$strApproximateCount = 'Poate fi aproximativ. Vezi FAQ 3.11';
$strArabic = 'Arabic';
$strArmenian = 'Armenian';
$strAscending = 'Crescatoare';
$strAtBeginningOfTable = 'La inceputul tabelului';
$strAtEndOfTable = 'La sfarsitul tabelului';
$strAttr = 'Proprietati';
$strAutodetect = 'Autodetectare';
$strAutomaticLayout = 'Layout automat';

$strBack = 'Inapoi';
$strBaltic = 'Baltic';
$strBeginCut = 'DE TAIAT - INCEPUT';
$strBeginRaw = 'INCEPUT RAW';
$strBinLogEventType = 'Tip eveniment';
$strBinLogInfo = 'Informatie';
$strBinLogName = 'Denumire Log';
$strBinLogOriginalPosition = 'Pozitie originala';
$strBinLogPosition = 'Pozitie';
$strBinLogServerId = 'Server ID';
$strBinary = 'Binar';
$strBinaryDoNotEdit = 'Binar - a nu se edita';
$strBinaryLog = 'Binary log';
$strBookmarkAllUsers = 'Permite tuturor utilizatorilor sa acceseze acest bookmark';
$strBookmarkDeleted = 'Eticheta a fost stearsa.';
$strBookmarkLabel = 'Eticheta - Label';
$strBookmarkQuery = 'Comanda SQL salvata (Bookmarked SQL-query)';
$strBookmarkThis = 'Salveaza aceasta comanda SQL';
$strBookmarkView = 'Numai vizualizare';
$strBrowse = 'Navigare';
$strBrowseForeignValues = 'Cauta printre valori necunoscute';
$strBulgarian = 'Bulgar';
$strBzError = 'phpMyAdmin nu a reusit sa compreseze acest dump din cauza unei extensii Bz2 invalide in aceasta versiune php. Va recomandam sa setati directiva <code>$cfg[\'BZipDump\']</code> in in fisierul de configurare phpMyAdmin la <code>FALSE</code>. Daca doriti sa utilizati caracteristicile de compresie Bz2 va trebui sa upgradati la o versiune mai noua de php.  Pentru detalii revedeti raportul de erori php %s.';
$strBzip = '"bzipped"';

$strCSVOptions = 'Optiuni CSV';
$strCalendar = 'Calendar';
$strCannotLogin = 'Nu pot face conexiunea catre serverul MySQL';
$strCantLoad = 'nu se poate incarca %s extensia,<br />va rugam verificati configuratia PHP.';
$strCantLoadRecodeIconv = 'Nu pot incarca extensia iconv sau recode necesar pentru conversia de caractere, configureaza PHP pentru a permite folosirea acestor extensii sau dezactiveaza conversia de caractere din phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Nu poti redenumi index-ul la un nume PRIMARY!';
$strCantUseRecodeIconv = 'Nu pot folosi functiile iconv nici libiconv nici recode_string in timp ce extensia este incarcata. Verifica configuratia PHP.';
$strCardinality = 'Cardinalitate';
$strCaseInsensitive = 'caz-insenzitiv';
$strCaseSensitive = 'caz-senzitiv';
$strCentralEuropean = 'European de est';
$strChange = 'Schimbare';
$strChangeCopyMode = 'Creaza un utilizatoru nou cu acelasi privilegii si...';
$strChangeCopyModeCopy = '... mentine cel vechi.';
$strChangeCopyModeDeleteAndReload = ' ... sterge cel vechi din tabela de utilizatori si reincarca privilegiile.';
$strChangeCopyModeJustDelete = ' ... sterge cel vechi din tabela de utilizatori.';
$strChangeCopyModeRevoke = ' ... revoca toate privilegiile active de la utilizatorul vechi si sterge-l dupa aceea.';
$strChangeCopyUser = 'Schimba informatiile de autentificare / Copiaza utilizator';
$strChangeDisplay = 'Selecteaza un camp';
$strChangePassword = 'Schimbare parola';
$strCharset = 'Set de caractere';
$strCharsetOfFile = 'Setul de caractere a fisierului:';
$strCharsets = 'Set de caractere';
$strCharsetsAndCollations = 'Set de caractere si gestionarea acestora';
$strCheckAll = 'Marcheaza toate';
$strCheckOverhead = 'Verificare depasit';
$strCheckPrivs = 'Verifica privilegiile';
$strCheckPrivsLong = 'Verifica privilegiile pentru baza de date &quot;%s&quot;.';
$strCheckTable = 'Verificare tabel';
$strChoosePage = 'Selecteaza o pagina pentru a fi editata';
$strColComFeat = 'Arata comentariile coloanei';
$strCollation = 'Gestionare';
$strColumnNames = 'Numele coloanelor';
$strColumnPrivileges = 'Drepturi specifice de coloana';
$strCommand = 'Comanda';
$strComments = 'Comentarii';
$strCommentsForTable = 'COMENTARII PENTRU TABEL';
$strCompatibleHashing = 'Compatibil MySQL&nbsp;4.0';
$strCompleteInserts = 'Rezolva inserarea';
$strCompression = 'Compresie';
$strConfigFileError = 'phpMyAdmin nu poate citi corect fisierul de configuratie!  <br />Acesta se poate intampla in cazul in care PHP nu poate gasi fisierul sau nu o poate parsa corect.  <br />Vezi configuratia fisierului apasand pe linkul de mai jos si citeste cu atentie erorile aparute ...  In cele mai multe cazuri lipsesc apostroful sau ghilimele.<br />Daca primesti o pagina goala, totul pare sa fie bine.';
$strConfigureTableCoord = 'Configureaza coordonatelepentru tabela %s';
$strConnectionError = 'Conexiune esuata: setari invalide.';
$strConnections = 'Conexiuni';
$strConstraintsForDumped = 'Restrictii pentru tabele sterse';
$strConstraintsForTable = 'Restrictii pentru tabele';
$strCookiesRequired = 'Trebuie sa aveti activat "cookies".';
$strCopyDatabaseOK = 'Baza de date %s a fost copiata la %s';
$strCopyTable = 'Copiaza tabela la (database<b>.</b>table):';
$strCopyTableOK = 'Tabelul %s a fost copiat la %s.';
$strCopyTableSameNames = 'Nu se poate copia tabelul pe cel existent pentru ca este acelasi';
$strCouldNotKill = 'phpMyAdmin n-a reusit sa opreasca firul de executie %s.  Probabil a fost deja oprit.';
$strCreate = 'Creaza';
$strCreateIndex = 'Creaza un index pe&nbsp;%s&nbsp;coloana';
$strCreateIndexTopic = 'Creaza un nou index';
$strCreateNewDatabase = 'Creaza baza de date noua';
$strCreateNewTable = 'Creaza tabela noua in baza de date %s';
$strCreatePage = 'Creaza o noua pagina';
$strCreatePdfFeat = 'Creare de PDF';
$strCreationDates = 'Creare/Reinnoire/Verificare data';
$strCriteria = 'Criteriu';
$strCroatian = 'Croat';
$strCyrillic = 'Cyrillic';
$strCzech = 'Ceh';
$strCzechSlovak = 'Czech-Slovak';

$strDBComment = 'Comentarii referitoare la baza de date: ';
$strDBCopy = 'Copiaza baza de date';
$strDBGContext = 'Context';
$strDBGContextID = 'Context ID';
$strDBGHits = 'Afisari';
$strDBGLine = 'Linia';
$strDBGMaxTimeMs = 'Timp maxim, ms';
$strDBGMinTimeMs = 'Timp minim, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'Timp/Afisare, ms';
$strDBGTotalTimeMs = 'Timp total, ms';
$strDBRename = 'Redenumire baza de date in';
$strDanish = 'Danez';
$strData = 'Date';
$strDataDict = 'Dictionar de date';
$strDataOnly = 'Numai date';
$strDatabase = 'Baza de date';
$strDatabaseEmpty = 'Campul de denumire a bazei de date este gol!';
$strDatabaseExportOptions = 'Optiuni de exportare a bazei de date';
$strDatabaseHasBeenDropped = 'Baza de date %s a fost aruncat.';
$strDatabaseNoTable = 'Aceasta baza de date nu contine nici un tabel!';
$strDatabases = 'Baze de date';
$strDatabasesDropped = '%s baza(ele) de data(e) au fost aruncate.';
$strDatabasesStats = 'Statisticile bazelor de date';
$strDatabasesStatsDisable = 'Dezactiveaza statisticile';
$strDatabasesStatsEnable = 'Activeaza statisticile';
$strDatabasesStatsHeavyTraffic = 'Nota: Activarea statisticilor pentru baza de date, poate cauza cresterea traficului intre MySQL si serverul de web.';
$strDbPrivileges = 'Drepturi specifice de baza de date';
$strDbSpecific = 'specific bazei de date';
$strDefault = 'Setare de baza';
$strDefaultEngine = '%s este motorul de stocare setat prin default pe acest server MySQL.';
$strDefaultValueHelp = 'Pentru valorile implicite, va rugam introduceti o singura valoare, fara backslash, escape sau ghilimele, folosind formatul: a';
$strDefragment = 'Defragmentare tablela';
$strDelOld = 'Pagina curenta se leaga de tabele care nu mai exista. Doriti stergerea acestor legaturi?';
$strDelayedInserts = 'Foloseste inserari intarziate';
$strDelete = 'Sterge';
$strDeleteAndFlush = 'Sterge utilizatorii si reincarca drepturile pe urma.';
$strDeleteAndFlushDescr = 'Este cea mai simpla metoda, dar reincarcarea drepturilor s-ar putea sa dureze.';
$strDeleted = 'Linia a fost stearsa';
$strDeletedRows = 'Randuri sterse:';
$strDeleting = 'Sterge %s';
$strDescending = 'Descrescator';
$strDescription = 'Descriere';
$strDictionary = 'dictionar';
$strDisableForeignChecks = 'Dezactivare verificari de cheie straine';
$strDisabled = 'Dezactivat';
$strDisplayFeat = 'Arata facilitatile';
$strDisplayOrder = 'Ordine de afisare:';
$strDisplayPDF = 'Arata schema PDF';
$strDoAQuery = 'Executa un "query by example" (wildcard: "%")';
$strDoYouReally = 'Sunteti sigur ca doriti sa ';
$strDocu = 'Documentatie';
$strDrop = 'Arunca';
$strDropDatabaseStrongWarning = 'Sunteti pe cale sa DISTRUGETI o intreaga baza de date!';
$strDropUsersDb = 'Arunca baza de date care are acelasi nume ca un utilizator.';
$strDumpSaved = 'Copia a fost salvata in fisierul %s.';
$strDumpXRows = 'Arunca %s randuri incepand de la randul %s.';
$strDumpingData = 'Salvarea datelor din tabel';
$strDynamic = 'dinamic';

$strEdit = 'Editare';
$strEditPDFPages = 'Editeaza paginile PDF';
$strEditPrivileges = 'Editeaza drepturile de acces';
$strEffective = 'Efectiv';
$strEmpty = 'Goleste';
$strEmptyResultSet = 'MySQL a dat un set de rezultate gol (ex. zero linii).';
$strEnabled = 'Activat';
$strEncloseInTransaction = 'Cuprinde exportare intr-o tranzactie';
$strEnd = 'Sfarsit';
$strEndCut = 'DE TAIAT - SFARSIT';
$strEndRaw = 'SFARSIT RAW';
$strEngineAvailable = '%s este disponibil pentru acest server de MySQL.';
$strEngineDisabled = '%s a fost dezactivat pentru acest server de MySQL.';
$strEngineUnsupported = 'Acest server MySQL nu suporta motorul de stocare %s.';
$strEngines = 'Motoare';
$strEnglish = 'Englez';
$strEnglishPrivileges = ' Important: numele drepturilor de acces MySQL apar in engleza ';
$strError = 'Eroare';
$strEscapeWildcards = 'Wildcard-urile _ si % trebuiesc insotite de \ pentru a le aplica';
$strEstonian = 'Estonian';
$strExcelEdition = 'Editia Excel';
$strExcelOptions = 'Optiuni Excel';
$strExecuteBookmarked = 'Executare comanda marcata';
$strExplain = 'Explica SQL';
$strExport = 'Export';
$strExtendedInserts = 'Inserari extinse';
$strExtra = 'Extra';

$strFailedAttempts = 'Incercari nereusite';
$strField = 'Camp';
$strFieldHasBeenDropped = 'Campul %s a fost aruncat';
$strFields = 'Campuri';
$strFieldsEmpty = ' Rezultat gol ';
$strFieldsEnclosedBy = 'Campuri incadrate de';
$strFieldsEscapedBy = 'Campuri realizate de';
$strFieldsTerminatedBy = 'Campuri terminate de';
$strFileAlreadyExists = 'Fisierul %s exista deja pe server, schimba denumirea fisierului sau bifeaza optiunea de suprascriere.';
$strFileCouldNotBeRead = 'Fisierul nu poate fi citit';
$strFileNameTemplate = 'Sablon nume fisier';
$strFileNameTemplateRemember = 'tine minte template';
$strFixed = 'fixat';
$strFlushPrivilegesNote = 'Nota: phpMyAdmin foloseste privilegiile utilizatorilor direct din tabela de privilegii din MySQL. Continutul acestei tabele poate diferi de cel original. In acest caz, reincarca de aici inainte de a continua %sreincarcarea drepturilor%s.';
$strFlushTable = 'Curatarea tabelului ("FLUSH")';
$strFormEmpty = 'Valoarea lipseste in formular !';
$strFormat = 'Format';
$strFullText = 'Texte intregi';
$strFunction = 'Functie';

$strGenBy = 'Generat de';
$strGenTime = 'Timp de generare';
$strGeneralRelationFeat = 'Facilitati generale';
$strGeorgian = 'Georgian';
$strGerman = 'German';
$strGlobal = 'global';
$strGlobalPrivileges = 'Privilegii globale';
$strGlobalValue = 'Valoare globala';
$strGo = 'Executa';
$strGrantOption = 'Grant';
$strGreek = 'Grec';
$strGzip = '"gzipped"';

$strHasBeenAltered = 'a fost alterat.';
$strHasBeenCreated = 'a fost creat.';
$strHaveToShow = 'Trebuie sa alegi cel putin o coloana pentru a putea afisa';
$strHebrew = 'Ebraica';
$strHexForBinary = 'Foloseste hexadecimal pentru campuri binary';
$strHome = 'Pagina de start';
$strHomepageOfficial = 'Pagina oficiala phpMyAdmin';
$strHost = 'Gazda (Host)';
$strHostEmpty = 'Numele de gazda este gol!';
$strHungarian = 'Unguresc';

$strIcelandic = 'Islandic';
$strId = 'ID';
$strIdxFulltext = 'Tot textul';
$strIgnore = 'Ignora';
$strIgnoreInserts = 'Utilizati ignorare inserari';
$strIgnoringFile = 'Fisier %s ignorat';
$strImportDocSQL = 'Import de fisiere docSQL';
$strImportFiles = 'Import de fisiere';
$strInUse = 'in folosinta';
$strIndex = 'Index';
$strIndexHasBeenDropped = 'Index %s a fost aruncat';
$strIndexName = 'Nume index&nbsp;:';
$strIndexType = 'Tip index&nbsp;:';
$strIndexWarningMultiple = 'S-a creat mai mult de o cheie %s la coloana `%s`';
$strIndexWarningPrimary = 'Cheile PRIMARY si INDEX nu trebuiesc setate ambele la coloana `%s`';
$strIndexWarningTable = 'Probleme cu indexul tabelului `%s`';
$strIndexWarningUnique = 'Cheile UNIQUE si INDEX nu trebuiesc setate ambele la coloana `%s`';
$strIndexes = 'Indexuri';
$strInnodbStat = 'InnoDB Status';
$strInsecureMySQL = 'Configurarea ta contine setarile ce baza (utilizator root fara parola). Serverul MySQL poate fi astfel vulnerabil, neaparat sa repari aceasta greseala.';
$strInsert = 'Inserare';
$strInsertAsNewRow = 'Insereaza ca o noua linie';
$strInsertNewRow = 'Insereaza o noua linie';
$strInsertedRowId = 'ID rand inserat:';
$strInsertedRows = 'Randuri inserate:';
$strInternalNotNecessary = '* Nu se cere o relatie interna in cazul in care exista si in InnoDB.';
$strInternalRelations = 'Relatii interne';

$strJapanese = 'Japonez';
$strJumpToDB = 'Sari la baza de date &quot;%s&quot;.';
$strJustDelete = 'Sterge utilizatorii din tabelele de drepturi.';
$strJustDeleteDescr = 'Utilizatorii &quot;stersi&quot; vor avea acces la server la fel ca pana acum pana ce drepturile sunt reincarcate.';

$strKeepPass = 'Nu schimbati parola';
$strKeyname = 'Nume cheie';
$strKill = 'Opreste';
$strKorean = 'Corean';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Optiuni LaTeX';
$strLandscape = 'Landscape';
$strLatexCaption = 'Captura tabel';
$strLatexContent = 'Continutul tabelului __TABLE__';
$strLatexContinued = '(continuare)';
$strLatexContinuedCaption = 'Continuare captura tabel';
$strLatexIncludeCaption = 'Include captura tabel';
$strLatexLabel = 'Tasta label';
$strLatexStructure = 'Structura tabelului __TABLE__';
$strLatvian = 'Leton';
$strLengthSet = 'Lungime/Setare';
$strLimitNumRows = 'Numarul de inregistrari de pe pagina';
$strLinesTerminatedBy = 'Linii terminate de';
$strLinkNotFound = 'Legatura invalida';
$strLinksTo = 'Trimitere la';
$strLithuanian = 'Lituanian';
$strLocalhost = 'Local';
$strLocationTextfile = 'Locatia fisierului text';
$strLogPassword = 'Parola:';
$strLogServer = 'Server';
$strLogUsername = 'Nume utilizator:';
$strLogin = 'Autentificare';
$strLoginInformation = 'Informatii de autentificare';
$strLogout = 'Deconectare';
$strLongOperation = 'Aceasta operatie poate dura mult. Doriti totusi sa fie executata?';

$strMIMETypesForTable = 'MIME TYPES PENTRU TABEL';
$strMIME_MIMEtype = 'MIME-type';
$strMIME_available_mime = 'Tipuri MIME disponibile';
$strMIME_available_transform = 'Informatii disponibile';
$strMIME_description = 'Descriere';
$strMIME_nodescription = 'Nu este disponibila nici o descriere pentru aceasta transformare.<br />Intrebati autorul de functiile indeplinite de %s.';
$strMIME_transformation = 'Transformare browser';
$strMIME_transformation_note = 'Pentru lista optiunilor de transformare disponibile si transformarile MIME-type, apasati pe %stransformation descriptions%s';
$strMIME_transformation_options = 'Optiuni de transformare';
$strMIME_transformation_options_note = 'Introduceti valorile pentru optiunile de transformare utilizand acest format: \'a\',\'b\',\'c\'...<br />Daca trebuie sa folositi backslash ("\") sau apostrof  ("\'") in aceste valori, introduceti un backslashes (ex. \'\\\\xyz\' sau \'a\\\'b\').';
$strMIME_without = 'Tipurile MIME listate inclinat nu au o functie de transformare separata';
$strMaximumSize = 'Marime maxima: %s%s';
$strMbExtensionMissing = 'Nu s-a gasit extensia PHP mbstring si se pare ca folositi set de charactere multibyte. Fara extensia mbstring, phpMyAdmin nu poate diviza stringurile corect si acesta poate duce la rezultate neasteptate.';
$strMbOverloadWarning = 'Ati activat mbstring.func_overload in configuratia PHP. Aceasta optiune nu este compatibila cu phpMyAdmin si poate duce la pierderea unor date!';
$strModifications = 'Modificarile au fost salvate';
$strModify = 'Modificare';
$strModifyIndexTopic = 'Modifica un index';
$strMoveTable = 'Muta tabela la (database<b>.</b>table):';
$strMoveTableOK = 'Tabela %s a fost mutat la %s.';
$strMoveTableSameNames = 'Nu se poate copia tabelul pe cel existent pentru ca este acelasi!';
$strMultilingual = 'Poliglot';
$strMyISAMDataPointerSize = 'Marime data pointer';
$strMyISAMDataPointerSizeDesc = 'Marimea pointer default in byti, care este folosit de CREATE TABLE pentru tabelele MyISAM atunci cand nu este specificat nici o optiune MAX_ROWS.';
$strMyISAMMaxExtraSortFileSize = 'Marimea maxima pentru fisierele temporare la crearea indexului';
$strMyISAMMaxExtraSortFileSizeDesc = 'Daca fisierul temporar utilizat pentru crearea rapida a indexului MyISAM ar fi mai mare decat daca s-ar utiliza cache-ul key. Se prefera utilizarea metodei key cache.';
$strMyISAMMaxSortFileSize = 'Marimea maxima pentru fisierele de sortare temporare';
$strMyISAMMaxSortFileSizeDesc = 'Marimea maxima pentru fisierul temporar care este permisa in MySQL in timpul recrearii unui index MyISAM (in timpul operatiunilor REPAIR TABLE, ALTER TABLE, sau LOAD DATA INFILE).';
$strMyISAMRecoverOptions = 'Mod de recuperare automat';
$strMyISAMRecoverOptionsDesc = 'Modul pentru recuperarea automata a tabelelor MyISAM deteriorate, setat prin optiunea startup --myisam-recover server.';
$strMyISAMRepairThreads = 'Repara firele de executie';
$strMyISAMRepairThreadsDesc = 'Daca aceasta valoare este mai mare decat 1, indexurile de tabel MyISAM sunt create in paralel (fiecare index in firul de executie propriu) in tipul operatiunii de reparare prin procesul de sortare.';
$strMyISAMSortBufferSize = 'Sortare marime buffer';
$strMyISAMSortBufferSizeDesc = 'Bufferul alocat la sortarea indexurilor MyISAM in timpul unei operatiuni REPAIR TABLE sau la crearea indexurilor cu CREATE INDEX sau ALTER TABLE.';
$strMySQLCharset = 'Setul de caractere MySQL';
$strMySQLSaid = 'MySQL zice: ';
$strMySQLShowProcess = 'Afiseaza procesele';
$strMySQLShowStatus = 'Afiseaza informatiile runtime MySQL';
$strMySQLShowVars = 'Afiseaza variabilele de sistem MySQL';

$strName = 'Nume';
$strNext = 'Urmatorul';
$strNo = 'Nu';
$strNoActivity = 'Nu ati avut activitate de mai mult de %s seconde, va rugam sa va autentificati din nou';
$strNoDatabases = 'Nu sunt baze de date';
$strNoDatabasesSelected = 'Nu este selectat nici o baza de date.';
$strNoDescription = 'Nu exista descriere';
$strNoDetailsForEngine = 'Nu exista informatii detaliate legate de status disponibile pentru motorul de stocare.';
$strNoDropDatabases = 'Comenzile "DROP DATABASE" sunt dezactivate.';
$strNoExplain = 'Sari peste explicarea SQL';
$strNoFrames = 'phpMyAdmin are o interfata mai prietenoasa cu navigator care lucreaza cu <b>frame-uri</b>.';
$strNoIndex = 'Index nu este definit!';
$strNoIndexPartsDefined = 'Nu sunt definite parti din index!';
$strNoModification = 'Nici o schimbare';
$strNoOptions = 'Acest format nu are optiuni';
$strNoPassword = 'Nu exista parola';
$strNoPermission = 'Serverul web nu poate salva fisierul %s.';
$strNoPhp = 'fara cod PHP';
$strNoPrivileges = 'Nu exista drepturi de acces';
$strNoRights = 'Nu detineti drepturi de acces pentru a va afla aici!';
$strNoRowsSelected = 'Nu e nici un rand selectat';
$strNoSpace = 'Spatiu insuficient pentru salvarea fisierului %s.';
$strNoTablesFound = 'Nu s-a gasit nici un tabel in baza de date.';
$strNoThemeSupport = 'Nu exista suport pentru themes, va rugam verificati configuratia si/sau designurile in directorul %s.';
$strNoUsersFound = 'Nu s-a gasit nici un utilizator.';
$strNoValidateSQL = 'Sari peste validarea SQL';
$strNone = 'Nici unul(a)';
$strNotNumber = 'Acesta nu este un numar!';
$strNotOK = 'Nu este bine';
$strNotSet = '<b>%s</b> tabela nu a fost gasita sau nu este setat in %s';
$strNull = 'Nul';
$strNumSearchResultsInTable = '%s rezultat(e) in interiorul tabelei <i>%s</i>';
$strNumSearchResultsTotal = '<b>Total:</b> <i>%s</i> rezultat(e)';
$strNumTables = 'Tabele';

$strOK = 'E bine';
$strOperations = 'Operatii';
$strOperator = 'Operator';
$strOptimizeTable = 'Optimizare tabel';
$strOr = 'Sau';
$strOverhead = 'Asupra';
$strOverwriteExisting = 'Suprascrie fisier(e) existent(e)';

$strPHP40203 = 'Folosesti PHP 4.2.3, server care are un bug major la multi-byte strings (mbstring). Vezi PHP bug report la 19404. Aceasta versiune de PHP nu este recomandat de folosit cu phpMyAdmin.';
$strPHPVersion = 'Versiune PHP';
$strPageNumber = 'Numarul paginii:';
$strPaperSize = 'Marime hartie';
$strPartialText = 'Texte partiale';
$strPassword = 'Parola';
$strPasswordChanged = 'Parola pentru %s a fost schimbata cu succes.';
$strPasswordEmpty = 'Parola este goala!';
$strPasswordNotSame = 'Parolele nu corespund!';
$strPdfDbSchema = 'Schema bazei de date "%s" - Pagina %s';
$strPdfInvalidTblName = 'Tabela "%s" nu exista!';
$strPdfNoTables = 'Nu exista tabele';
$strPerHour = 'pe ora';
$strPerMinute = 'pe minute';
$strPerSecond = 'pe secunde';
$strPersian = 'Persian';
$strPhoneBook = 'carte de telefoane';
$strPhp = 'Creaza cod PHP';
$strPmaDocumentation = 'Documentatie phpMyAdmin';
$strPmaUriError = 'Directiva <tt>$cfg[\'PmaAbsoluteUri\']</tt> TREBUIE sa fie setat in fisierul de configurare!';
$strPolish = 'Polononez';
$strPortrait = 'Portrait';
$strPos1 = 'Incepe';
$strPrevious = 'Anterior';
$strPrimary = 'Primar';
$strPrimaryKeyHasBeenDropped = 'Cheia primara a fost aruncat';
$strPrimaryKeyName = 'Numele cheii primare trebuie sa fie ... PRIMARY!';
$strPrimaryKeyWarning = '("Numele PRIMARY" <b>trebuie</b> sa fie <b>numai la</b> cheie primara!)';
$strPrint = 'Listare';
$strPrintView = 'Viziualizare imprimare';
$strPrintViewFull = 'Vizualizare listare4 (impreuna cu text)';
$strPrivDescAllPrivileges = 'Include toate privilegiile, excluzand GRANT.';
$strPrivDescAlter = 'Permite alterarea structurii la tabelele deja existente.';
$strPrivDescCreateDb = 'Permite crearea de noi baze de date si tabele.';
$strPrivDescCreateTbl = 'Permite crearea de noi tabele.';
$strPrivDescCreateTmpTable = 'Permite crearea de tabele temporare.';
$strPrivDescDelete = 'Permite stergere de date.';
$strPrivDescDropDb = 'Permite stergerea unei baze de date sau a unor tabele.';
$strPrivDescDropTbl = 'Permite aruncarea a unei baze de date.';
$strPrivDescExecute = 'Permite rularea procedurilor stocate; Nu are efect in aceasta versiune MySQL.';
$strPrivDescFile = 'Permite importarea datelor in fisiere si exportarea acestora din fisiere.';
$strPrivDescGrant = 'Permite adaugarea utilizatorilor si drepturilor fara reincarcarea tabelelor de drepturi.';
$strPrivDescIndex = 'Permite crearea si stergerea indexelor.';
$strPrivDescInsert = 'Permite inserarea si inlocuirea datelor.';
$strPrivDescLockTables = 'Permite blocarea tabelelor din firul curent de executie.';
$strPrivDescMaxConnections = 'Limiteaza numarul de noi conexiuni care pot fi deschise de utilizator intr-o ora.';
$strPrivDescMaxQuestions = 'Limiteaza numarul de comenzi care pot fi trimise de utilizator catre server intr-o ora.';
$strPrivDescMaxUpdates = 'Limiteaza numarul de comenzi pentru schimbarea vreunui tabel sau vreunei baza de date executabile de utilizator intr-o ora.';
$strPrivDescProcess3 = 'Permite oprirea proceselor altor utilizatori.';
$strPrivDescProcess4 = 'Permite vizualizarea comenzilor procesate in lista.';
$strPrivDescReferences = 'Nu are efect in aceasta versiune MySQL.';
$strPrivDescReload = 'Permite reincarcarea setarilor de server si golirea memoriei cache a serverului.';
$strPrivDescReplClient = 'Permite utilizatorului de a interoga locatia slave/master.';
$strPrivDescReplSlave = 'Necesara pentru slave replication.';
$strPrivDescSelect = 'Permite citirea datelor.';
$strPrivDescShowDb = 'Permite accesul la lista completa a bazelor de date.';
$strPrivDescShutdown = 'Permite oprirea serverului.';
$strPrivDescSuper = 'Permite conoxiuni, chiar daca s-a atins numarul maxim de conexiuni; Necesara pentru majoritatea operatiunilor administrative cum ar fi setarea variabilelor globale sau oprirea fierlor de executie a altor utilizatori.';
$strPrivDescUpdate = 'Permite schimbarea datelor.';
$strPrivDescUsage = 'Fara drepturi.';
$strPrivileges = 'Drepturi de acces';
$strPrivilegesReloaded = 'Drepturile au fost reincarcate cu succes.';
$strProcesslist = 'Lista procese';
$strPutColNames = 'Pune numele filed-ului in primul rand';

$strQBE = 'Comanda prin exemplu (Query by Example)';
$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQueryFrame = 'Fereastra de comanda';
$strQueryOnDb = 'Comanda SQL pe baza de date <b>%s</b>:';
$strQuerySQLHistory = 'SQL-history';
$strQueryStatistics = '<b>Statistica interogari</b>: De la inceput, s-au trimis %s interogari la server.';
$strQueryTime = 'Comanda a durat %01.4f sec';
$strQueryType = 'Tip interogare';
$strQueryWindowLock = 'A nu se suprascrie peste aceasta interogare din cealalta fereastra';

$strReType = 'Re-type';
$strReceived = 'Receptionat';
$strRecords = 'Inregistrari';
$strReferentialIntegrity = 'Verificarea integritatii referentiei:';
$strRefresh = 'Reincarca';
$strRelationNotWorking = 'Optiunile aditionale pentru folosirea tabelelor intercalate (legate intre ele) au fost dezactivate. Pentru a afla de ce ...  %shere%s.';
$strRelationView = 'Vizualizare relationala';
$strRelationalSchema = 'Schema relationala';
$strRelations = 'Legaturi';
$strRelationsForTable = 'RELATII PENTRU TABEL';
$strReloadMySQL = 'Reincarcare MySQL';
$strReloadingThePrivileges = 'Reincarcarea drepturilor';
$strRemoveSelectedUsers = 'Eliminarea utilizatorilor selectati';
$strRenameDatabaseOK = 'Baza de date %s a fost redenumita in %s';
$strRenameTable = 'Rename tabel la';
$strRenameTableOK = 'Tabelului %s i s-a dat un numele de %s';
$strRepairTable = 'Reparare tabel';
$strReplaceNULLBy = 'Inlocuire NULL cu';
$strReplaceTable = 'Inlocuieste datele tabelului cu fisier';
$strReset = 'Resetare';
$strResourceLimits = 'Limitare de resurse';
$strRevoke = 'Revocare';
$strRevokeAndDelete = 'Revocarea tuturor drepturilor active a utilizatorilor si stergerea acestora.';
$strRevokeAndDeleteDescr = 'Utilizatorii vor avea in continuare drepturi de UTILIZARE pana ce drepturile se reincarca.';
$strRevokeMessage = 'Drepturile tale au fost revocate pentru %s';
$strRomanian = 'Roman';
$strRowLength = 'Lungime linie';
$strRowSize = ' Marime linie ';
$strRows = 'Linie';
$strRowsFrom = 'linii incepand cu';
$strRowsModeFlippedHorizontal = 'orizontal (antet rotativ)';
$strRowsModeHorizontal = 'orizontal';
$strRowsModeOptions = 'in mod %s si repetare antet dupa %s celule';
$strRowsModeVertical = 'vertical';
$strRowsStatistic = 'Statisticile randului';
$strRunQuery = 'Trimite comanda';
$strRunSQLQuery = 'Run SQL query/queries pe baza de date %s';
$strRunning = 'ruland pe %s';
$strRussian = 'Rus';

$strSQL = 'SQL';
$strSQLExportCompatibility = 'Compatibilitate SQL export';
$strSQLExportType = 'Modul de export';
$strSQLOptions = 'Optiuni SQL';
$strSQLParserBugMessage = 'Exista o posibilitate de a fi gasit un BUG in parserul SQL. Verifica atent inca o data comanda si verifica daca semnele specifice sunt corecte. O alta posibilitate ar putea fi punerea unui fisier binar in afara zonei de text. Poti incerca aceasta comanda si printr-o linie de comanda MySQL. Eroarea MySQL de mai jos, daca e vreuna, poate sa te ajute la diagnosticarea problemei. Daca in continuare ai probleme cu executarea comenzii, redu o parte din comanda la aceea parte care cauzeaza problema si raporteaza acesta ca un BUG in sectiunea DE TAIAT';
$strSQLParserUserError = 'Pare sa fie o eroare in comanda SQL. Eroarea MySQL de mai jos, daca e vreuna, poate sa te ajute la diagnosticarea problemei';
$strSQLQuery = 'Comanda SQL';
$strSQLResult = 'Rezultat SQL';
$strSQPBugInvalidIdentifer = 'Identificator invalid';
$strSQPBugUnclosedQuote = 'Citare neinchisa';
$strSQPBugUnknownPunctuation = 'Insiruire de punctuatie necunoscuta';
$strSave = 'Salveaza';
$strSaveOnServer = 'Salveaza pe server in directorul %s';
$strScaleFactorSmall = 'Factorul de scalare este prea mica pentru a inchepe in pagina';
$strSearch = 'Cauta';
$strSearchFormTitle = 'Cauta in baza de date';
$strSearchInTables = 'In interiorul tabelei(lor):';
$strSearchNeedle = 'Cuvant(e) sau valoare(ori) de cautat pentru (wildcard: "%"):';
$strSearchOption1 = 'cel putin una dintre cuvinte';
$strSearchOption2 = 'toate cuvintele';
$strSearchOption3 = 'fraza exacta';
$strSearchOption4 = 'ca o expresie';
$strSearchResultsFor = 'Cauta rezultate pentru "<i>%s</i>" %s:';
$strSearchType = 'Gaseste:';
$strSecretRequired = 'Fisierul de configurare necesita e expresie de protectie secreta (blowfish_secret).';
$strSelectADb = 'Selectati baza de date';
$strSelectAll = 'Selecteaza tot';
$strSelectBinaryLog = 'Selectati binary log pentru vizualizare';
$strSelectFields = 'Selecteaza campurile (cel putin unul):';
$strSelectNumRows = 'in comanda (in query)';
$strSelectTables = 'Selecteaza tabele';
$strSend = 'Trimite';
$strSent = 'Trimis';
$strServer = 'Server';
$strServerChoice = 'Alegerea serverului';
$strServerNotResponding = 'Serverul nu raspunde';
$strServerStatus = 'Informatii rulare';
$strServerStatusUptime = 'Acest server MySQL ruleaza de %s. S-a lansat la %s.';
$strServerTabProcesslist = 'Procese';
$strServerTabVariables = 'Variabile';
$strServerTrafficNotes = '<b>Server trafic</b>: Aceste tabele arata statistica de trafic in retea al acestui server MySQL de la lansare.';
$strServerVars = 'Variabile si setari de server';
$strServerVersion = 'Versiune server';
$strSessionValue = 'Valoare sesiune';
$strSetEnumVal = 'Daca campul este "enum" sau "set", va rugam adaugati valori folosind formatul: \'a\',\'b\',\'c\'...<br />Daca aveti nevoie sa puneti bara intoarsa (backslash) ("\") sau semnul ("\'") la aceste valori, folositi exemplul ( \'\\\\xyz\' or \'a\\\'b\').';
$strShow = 'Afiseaza';
$strShowAll = 'Arata toate';
$strShowColor = 'Arata culoarea';
$strShowDatadictAs = 'Data Dictionary Format';
$strShowFullQueries = 'Afisare comanda intreaga';
$strShowGrid = 'Arata grila';
$strShowPHPInfo = 'Arata informatia PHP';
$strShowTableDimension = 'Arata dimensiunile tabelei';
$strShowTables = 'Arata tabelele';
$strShowThisQuery = ' Afiseaza aceasta comanda din nou aici ';
$strShowingRecords = 'Afiseaza inregistrari';
$strSimplifiedChinese = 'Chineza simplificata';
$strSingly = '(singly)';
$strSize = 'Marime';
$strSlovak = 'Slovac';
$strSlovenian = 'Sloven';
$strSort = 'Sortare';
$strSortByKey = 'Sortare dupa tasta';
$strSpaceUsage = 'Utilizare spatiu';
$strSpanish = 'Spaniola';
$strSplitWordsWithSpace = 'Cuvinte sparte de un spatiu (" ").';
$strStatCheckTime = 'Ultima verficare';
$strStatCreateTime = 'Creatie';
$strStatUpdateTime = 'Ultimul update';
$strStatement = 'Comenzi';
$strStatus = 'Status';
$strStorageEngine = 'Motor de stocare';
$strStorageEngines = 'Motoare de stocare';
$strStrucCSV = 'Date CSV';
$strStrucData = 'Structura si date';
$strStrucDrop = 'Adauga \'salveaza tabel\'';
$strStrucExcelCSV = 'Date CSV pentru MS Excel';
$strStrucNativeExcel = 'Date native MS Excel';
$strStrucOnly = 'Numai structura';
$strStructPropose = 'Propune structura de tabele';
$strStructure = 'Structura';
$strSubmit = 'Trimite';
$strSuccess = 'Comanda dumneavoastra SQL a fost executata cu succes';
$strSum = 'Sum';
$strSwedish = 'Suedez';
$strSwitchToDatabase = 'Schimba la tabela copiata';
$strSwitchToTable = 'Schimba la tabela copiata';

$strTable = 'Tabel';
$strTableComments = 'Comentarii tabel';
$strTableEmpty = 'Numele de tabel este gol!';
$strTableHasBeenDropped = 'Tabelul %s a fost aruncat';
$strTableHasBeenEmptied = 'Tabelul %s a fost golit';
$strTableHasBeenFlushed = 'Tabelul %s a fost curatat';
$strTableMaintenance = 'Administrare tabel';
$strTableOfContents = 'Sumar';
$strTableOptions = 'Optiuni tabel';
$strTableStructure = 'Structura de tabel pentru tabelul';
$strTableType = 'Tipul tabelului';
$strTables = '%s tabele';
$strTakeIt = 'alege';
$strTblPrivileges = 'Drepturi specifice de tabele';
$strTextAreaLength = ' Datorita lungimii sale, <br /> acest camp s-ar putea sa nu fie editabil';
$strThai = 'Tailandez';
$strTheme = 'Sablon / Stil';
$strThisHost = 'Acest Host';
$strThisNotDirectory = 'Acesta nu este un director';
$strThreadSuccessfullyKilled = 'Firul de executie %s a fost oprit cu succes.';
$strTime = 'Timp';
$strToggleScratchboard = 'dezactivare scratchboard';
$strTotal = 'total';
$strTotalUC = 'Total';
$strTraditionalChinese = 'Chineza Traditionala';
$strTraditionalSpanish = 'Spaniola traditionala';
$strTraffic = 'Trafic';
$strTransformation_application_octetstream__download = 'Afiseaza un link pentru descarcarea datelor binare a unui camp. Prima optiune este denumirea fisierului binar. A doua optiune este o denumire posibila pentru un rand de tabel care contine denumirea de fisier. Daca setati si o a doua optiune, trebuie sa aveti prima optiune setata ca si empty string';
$strTransformation_image_jpeg__inline = 'Afiseaza o imagine mica clicabila ; optiuni: latime, inaltime in pixeli (metine dimensiunile originale)';
$strTransformation_image_jpeg__link = 'Afiseaza un link la imagine (direct blob download, i.e.).';
$strTransformation_image_png__inline = 'Vezi imagine/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Ia un camp TIME, TIMESTAMP sau DATETIME si il formateaza folosind format local de data. Prima optiune este offsetul (in ore) care se va adauga la (Default: 0).  A doua optiune este un forma de data diferit bazat pe parametri disponibili pentru PHP strftime().';
$strTransformation_text_plain__external = 'NUMAI LINUX: Lanseaza o aplicatie externa si trimite datele prin input standard. Returneaza standard output a aplicatiei. Default este Tidy, pentru listarea codului HTML. Din motive de securitate, va trebui sa editati manual fisierul libraries/transformations/text_plain__external.inc.php si sa inserati uneltele permise sa ruleze. Prima optiune este apoi numarul de programe care vor fi utilizate si a doua optiune sunt  parametri pentru program. Al treilea parametru, daca este setat la 1 va transforma outputul folosind htmlspecialchars() (Default este 1). Un al patrulea parametru, daca este setat la 1 va aplica NOWRAP la continut, astfel incat intregul output va fi afisat fara reformatare (Default 1)';
$strTransformation_text_plain__formatted = 'Mentine formatarea originala a campului.';
$strTransformation_text_plain__imagelink = 'Afiseaza o imagine si un link, campul contine denumirea fisierului; prima optiune este un prefix cum ar fi "http://domain.com/", a doua optiune este latimea in pixeli, iar a treia este inaltimea.';
$strTransformation_text_plain__link = 'Afiseaza un link, campul contine denumirea fisierului,  prima optiune este un prefix cum ar fi "http://domain.com/", a doua optiune este un titlu pentru link.';
$strTransformation_text_plain__substr = 'Afiseaza doar o parte a firului de executie. Prima optiune este un offset pentru definirea punctului de inceput a outputului de text (Default 0). A doua optiune este un offset de text returnat. Daca este gol, returneaza textul ramas. A treia optiune defineste caracterele care vor fi atasate la output la returnarea unui substring  (Default: ...) .';
$strTruncateQueries = 'Truncare comenzi afisate';
$strTurkish = 'Turc';
$strType = 'Tip';

$strUkrainian = 'Ukrainian';
$strUncheckAll = 'Deselecteaza toate';
$strUnicode = 'Unicode';
$strUnique = 'Unic';
$strUnknown = 'necunoscut';
$strUnselectAll = 'Deselecteaza tot';
$strUpdComTab = 'Parcurgeti documentatia pentru modul de updatare a Column_comments Table';
$strUpdatePrivMessage = 'Ati actualizat privilegiile pentru %s.';
$strUpdateProfileMessage = 'Profilul a fost actualizat.';
$strUpdateQuery = 'Reinnoire comanda';
$strUpgrade = 'Ar trebui sa reactualizati serverul %s %s la o versiune mai noua.';
$strUsage = 'Utilizare';
$strUseBackquotes = 'Utilizati apostroful pentru numele tabelelor si a campurilor';
$strUseHostTable = 'Utilizare tabel host';
$strUseTabKey = 'Folositi tasta TAB pentru a trece de la o valoare la alta sau CTRL+sageti pentru a merge in oricare directie';
$strUseTables = 'Utilizare tabele';
$strUseTextField = 'Utilizare camp text';
$strUseThisValue = 'Foloseste aceasta valoare';
$strUser = 'Utilizator';
$strUserAlreadyExists = 'Acest utilizator %s exista deja!';
$strUserEmpty = 'Numele de utilizator este gol!';
$strUserName = 'Nume de utilizator';
$strUserNotFound = 'Utilizatorul selectat nu s-a gasit in tabelul de drepturi.';
$strUserOverview = 'Descriere utilizator';
$strUsersDeleted = 'Utilizatorii selectati s-au sters cu succes.';
$strUsersHavingAccessToDb = 'Utilizatorul are acces la &quot;%s&quot;';

$strValidateSQL = 'Valideaza SQL';
$strValidatorError = 'Validatorul SQL nu poate fi initializat. Verifica daca e instalat extesnsia necesara PHP asa cum e descris in %sdocumentation%s.';
$strValue = 'Valoare';
$strVar = 'Variabil';
$strVersionInformation = 'Informatii despre versiune';
$strView = 'Vizualizare';
$strViewDump = 'Vizualizarea schemei tabelului';
$strViewDumpDB = 'Vizualizarea schemei bazei de date';
$strViewDumpDatabases = 'Vizualizarea schemei bazei de date';
$strViewHasBeenDropped = 'Vizualizarea %s a fost eliminata';

$strWebServerUploadDirectory = 'director de upload al web-server-ului';
$strWebServerUploadDirectoryError = 'Directorul setat pentru upload nu poate fi gasit';
$strWelcome = 'Bine ai venit la %s';
$strWestEuropean = 'European de vest';
$strWildcard = 'wildcard';
$strWindowNotFound = 'Fereastra de navigare nu a putut fi reincarcat.  Poate aceasta nu a fost inchis, sau fereastra parinte blocheaza ferestrele din cauza securitatii sistemului.';
$strWithChecked = 'Verificat cu:';
$strWritingCommentNotPossible = 'Scrierea unui comentariu nu este posibil';
$strWritingRelationNotPossible = 'Scrierea unei relatii nu este posibil';
$strWrongUser = 'Nume de utilizator/Parola incorecta. Accesul interzis.';

$strXML = 'XML';

$strYes = 'Da';

$strZeroRemovesTheLimit = 'Observatie: Prin setarea acestor optiuni la 0 (zero) se elimina restrictia.';
$strZip = '"arhivat"';

// To translate:

$strMySQLConnectionCollation = 'MySQL connection collation'; //to translate

$strPasswordHashing = 'Password Hashing';  //to translate

$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
$strCSV = 'CSV';  //to translate
$strImport = 'Import';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strFileToImport = 'File to import';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate
$strPartialImport = 'Partial import';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate
$strHandler = 'Handler';  //to translate
$strJoins = 'Joins';  //to translate
$strKeyCache = 'Key cache';  //to translate
$strMaxConnects = 'max. concurrent connections';  //to translate
$strQueryCache = 'Query cache';  //to translate
$strReplication = 'Replication';  //to translate
$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSorting = 'Sorting';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThreads = 'Threads';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
$strEsperanto = 'Esperanto';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strFileNameTemplateDescriptionTable = 'table name';  //to translate
$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
$strFileNameTemplateDescriptionServer = 'server name';  //to translate
$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strProtocolVersion = 'Protocol version';  //to translate
$strMysqlClientVersion = 'MySQL client version';  //to translate
$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
$strPDF = 'PDF';  //to translate
$strPDFOptions = 'PDF options';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
$strThemeNotFound = 'Theme %s not found!';  //to translate
$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
$strSQLImportOptions = 'SQL options';  //to translate
$strBrowseDistinctValues = 'Browse distinct values';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
?>
